# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aom_framework/services.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from aom_framework import protocols_pb2 as aom__framework_dot_protocols__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='aom_framework/services.proto',
  package='aom_api',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x1c\x61om_framework/services.proto\x12\x07\x61om_api\x1a\x1d\x61om_framework/protocols.proto2\x8a\x01\n\x0b\x45nvironment\x12;\n\x05Start\x12\x18.aom_api.EnvStartRequest\x1a\x16.aom_api.EnvStartReply\"\x00\x12>\n\x06Update\x12\x19.aom_api.EnvUpdateRequest\x1a\x17.aom_api.EnvUpdateReply\"\x00\x32\x8b\x02\n\x05Trial\x12?\n\x05Start\x12\x1a.aom_api.TrialStartRequest\x1a\x18.aom_api.TrialStartReply\"\x00\x12\x39\n\x03\x45nd\x12\x18.aom_api.TrialEndRequest\x1a\x16.aom_api.TrialEndReply\"\x00\x12\x42\n\x06\x41\x63tion\x12\x1b.aom_api.TrialActionRequest\x1a\x19.aom_api.TrialActionReply\"\x00\x12\x42\n\x06Reward\x12\x1b.aom_api.TrialRewardRequest\x1a\x19.aom_api.TrialRewardReply\"\x00\x32\xd0\x01\n\x05\x41gent\x12?\n\x05Start\x12\x1a.aom_api.AgentStartRequest\x1a\x18.aom_api.AgentStartReply\"\x00\x12\x42\n\x06\x44\x65\x63ide\x12\x1b.aom_api.AgentDecideRequest\x1a\x19.aom_api.AgentDecideReply\"\x00\x12\x42\n\x06Reward\x12\x1b.aom_api.AgentRewardRequest\x1a\x19.aom_api.AgentRewardReply\"\x00\x62\x06proto3')
  ,
  dependencies=[aom__framework_dot_protocols__pb2.DESCRIPTOR,])



_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_ENVIRONMENT = _descriptor.ServiceDescriptor(
  name='Environment',
  full_name='aom_api.Environment',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=73,
  serialized_end=211,
  methods=[
  _descriptor.MethodDescriptor(
    name='Start',
    full_name='aom_api.Environment.Start',
    index=0,
    containing_service=None,
    input_type=aom__framework_dot_protocols__pb2._ENVSTARTREQUEST,
    output_type=aom__framework_dot_protocols__pb2._ENVSTARTREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='aom_api.Environment.Update',
    index=1,
    containing_service=None,
    input_type=aom__framework_dot_protocols__pb2._ENVUPDATEREQUEST,
    output_type=aom__framework_dot_protocols__pb2._ENVUPDATEREPLY,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_ENVIRONMENT)

DESCRIPTOR.services_by_name['Environment'] = _ENVIRONMENT


_TRIAL = _descriptor.ServiceDescriptor(
  name='Trial',
  full_name='aom_api.Trial',
  file=DESCRIPTOR,
  index=1,
  serialized_options=None,
  serialized_start=214,
  serialized_end=481,
  methods=[
  _descriptor.MethodDescriptor(
    name='Start',
    full_name='aom_api.Trial.Start',
    index=0,
    containing_service=None,
    input_type=aom__framework_dot_protocols__pb2._TRIALSTARTREQUEST,
    output_type=aom__framework_dot_protocols__pb2._TRIALSTARTREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='End',
    full_name='aom_api.Trial.End',
    index=1,
    containing_service=None,
    input_type=aom__framework_dot_protocols__pb2._TRIALENDREQUEST,
    output_type=aom__framework_dot_protocols__pb2._TRIALENDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Action',
    full_name='aom_api.Trial.Action',
    index=2,
    containing_service=None,
    input_type=aom__framework_dot_protocols__pb2._TRIALACTIONREQUEST,
    output_type=aom__framework_dot_protocols__pb2._TRIALACTIONREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Reward',
    full_name='aom_api.Trial.Reward',
    index=3,
    containing_service=None,
    input_type=aom__framework_dot_protocols__pb2._TRIALREWARDREQUEST,
    output_type=aom__framework_dot_protocols__pb2._TRIALREWARDREPLY,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_TRIAL)

DESCRIPTOR.services_by_name['Trial'] = _TRIAL


_AGENT = _descriptor.ServiceDescriptor(
  name='Agent',
  full_name='aom_api.Agent',
  file=DESCRIPTOR,
  index=2,
  serialized_options=None,
  serialized_start=484,
  serialized_end=692,
  methods=[
  _descriptor.MethodDescriptor(
    name='Start',
    full_name='aom_api.Agent.Start',
    index=0,
    containing_service=None,
    input_type=aom__framework_dot_protocols__pb2._AGENTSTARTREQUEST,
    output_type=aom__framework_dot_protocols__pb2._AGENTSTARTREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Decide',
    full_name='aom_api.Agent.Decide',
    index=1,
    containing_service=None,
    input_type=aom__framework_dot_protocols__pb2._AGENTDECIDEREQUEST,
    output_type=aom__framework_dot_protocols__pb2._AGENTDECIDEREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Reward',
    full_name='aom_api.Agent.Reward',
    index=2,
    containing_service=None,
    input_type=aom__framework_dot_protocols__pb2._AGENTREWARDREQUEST,
    output_type=aom__framework_dot_protocols__pb2._AGENTREWARDREPLY,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_AGENT)

DESCRIPTOR.services_by_name['Agent'] = _AGENT

# @@protoc_insertion_point(module_scope)
