# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aom_framework/protocols.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='aom_framework/protocols.proto',
  package='aom_api',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x1d\x61om_framework/protocols.proto\x12\x07\x61om_api\x1a\x1fgoogle/protobuf/timestamp.proto\"\\\n\x08\x45nvState\x12\x0f\n\x07tick_id\x18\x01 \x01(\x04\x12.\n\ntime_stamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07\x63ontent\x18\x03 \x01(\x0c\"P\n\rEnvStateDelta\x12.\n\ntime_stamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\x0c\"r\n\x0bRewardEvent\x12\x10\n\x08\x61gent_id\x18\x01 \x01(\r\x12\x0f\n\x07tick_id\x18\x02 \x01(\r\x12\x14\n\x0creward_value\x18\x03 \x01(\x02\x12\x19\n\x11reward_confidence\x18\x04 \x01(\x02\x12\x0f\n\x07\x63ontent\x18\x05 \x01(\x0c\" \n\rAgentDecision\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\x0c\"$\n\x11TrialStartRequest\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\x0c\"w\n\x0fTrialStartReply\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\x0c\x12\x11\n\tplayer_id\x18\x02 \x01(\x04\x12\x12\n\nsession_id\x18\x03 \x01(\t\x12,\n\x11initial_sim_state\x18\x04 \x01(\x0b\x32\x11.aom_api.EnvState\"%\n\x0fTrialEndRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\"\x0f\n\rTrialEndReply\"9\n\x12TrialActionRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\x0c\"9\n\x10TrialActionReply\x12%\n\x05\x64\x65lta\x18\x01 \x01(\x0b\x32\x16.aom_api.EnvStateDelta\"&\n\x10TrialRewardValue\x12\x12\n\nsession_id\x18\x01 \x01(\t\"N\n\x12TrialRewardRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12$\n\x06reward\x18\x02 \x01(\x0b\x32\x14.aom_api.RewardEvent\"\x12\n\x10TrialRewardReply\"W\n\x0f\x45nvStartRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x30\n\x0cuser_request\x18\x02 \x01(\x0b\x32\x1a.aom_api.TrialStartRequest\"Q\n\rEnvStartReply\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12,\n\x11initial_sim_state\x18\x02 \x01(\x0b\x32\x11.aom_api.EnvState\"\xc1\x01\n\x10\x45nvUpdateRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x35\n\tuser_data\x18\x02 \x03(\x0b\x32\".aom_api.EnvUpdateRequest.UserData\x12*\n\nagent_data\x18\x03 \x03(\x0b\x32\x16.aom_api.AgentDecision\x12\x19\n\x11\x63reate_checkpoint\x18\x04 \x01(\x08\x1a\x1b\n\x08UserData\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\x0c\"\x84\x01\n\x0e\x45nvUpdateReply\x12%\n\x05\x64\x65lta\x18\x01 \x01(\x0b\x32\x16.aom_api.EnvStateDelta\x12$\n\tenv_state\x18\x02 \x01(\x0b\x32\x11.aom_api.EnvState\x12%\n\x07rewards\x18\x03 \x03(\x0b\x32\x14.aom_api.RewardEvent\"Y\n\x11\x41gentStartRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x30\n\x0cuser_request\x18\x02 \x01(\x0b\x32\x1a.aom_api.TrialStartRequest\"\x11\n\x0f\x41gentStartReply\"y\n\x12\x41gentDecideRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12$\n\tenv_state\x18\x02 \x01(\x0b\x32\x11.aom_api.EnvState\x12)\n\tenv_delta\x18\x03 \x01(\x0b\x32\x16.aom_api.EnvStateDelta\"<\n\x10\x41gentDecideReply\x12(\n\x08\x64\x65\x63ision\x18\x01 \x01(\x0b\x32\x16.aom_api.AgentDecision\"N\n\x12\x41gentRewardRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12$\n\x06reward\x18\x02 \x01(\x0b\x32\x14.aom_api.RewardEvent\"\x12\n\x10\x41gentRewardReply\"\xce\x01\n\x0e\x44\x61talog_sample\x12\x10\n\x08trial_id\x18\x01 \x01(\t\x12.\n\ntime_stamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x11\n\tenv_state\x18\x03 \x01(\x0c\x12\x11\n\tenv_delta\x18\x04 \x01(\x0c\x12\x14\n\x0c\x61gent_action\x18\x05 \x01(\x0c\x12\x13\n\x0buser_action\x18\x06 \x01(\x0c\x12\x14\n\x0c\x61gent_reward\x18\x07 \x01(\x02\x12\x13\n\x0buser_reward\x18\x08 \x01(\x02\x62\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])




_ENVSTATE = _descriptor.Descriptor(
  name='EnvState',
  full_name='aom_api.EnvState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tick_id', full_name='aom_api.EnvState.tick_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='aom_api.EnvState.time_stamp', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content', full_name='aom_api.EnvState.content', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=75,
  serialized_end=167,
)


_ENVSTATEDELTA = _descriptor.Descriptor(
  name='EnvStateDelta',
  full_name='aom_api.EnvStateDelta',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='aom_api.EnvStateDelta.time_stamp', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content', full_name='aom_api.EnvStateDelta.content', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=169,
  serialized_end=249,
)


_REWARDEVENT = _descriptor.Descriptor(
  name='RewardEvent',
  full_name='aom_api.RewardEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='agent_id', full_name='aom_api.RewardEvent.agent_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tick_id', full_name='aom_api.RewardEvent.tick_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reward_value', full_name='aom_api.RewardEvent.reward_value', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reward_confidence', full_name='aom_api.RewardEvent.reward_confidence', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content', full_name='aom_api.RewardEvent.content', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=251,
  serialized_end=365,
)


_AGENTDECISION = _descriptor.Descriptor(
  name='AgentDecision',
  full_name='aom_api.AgentDecision',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='content', full_name='aom_api.AgentDecision.content', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=367,
  serialized_end=399,
)


_TRIALSTARTREQUEST = _descriptor.Descriptor(
  name='TrialStartRequest',
  full_name='aom_api.TrialStartRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='content', full_name='aom_api.TrialStartRequest.content', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=401,
  serialized_end=437,
)


_TRIALSTARTREPLY = _descriptor.Descriptor(
  name='TrialStartReply',
  full_name='aom_api.TrialStartReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='content', full_name='aom_api.TrialStartReply.content', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='player_id', full_name='aom_api.TrialStartReply.player_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='session_id', full_name='aom_api.TrialStartReply.session_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='initial_sim_state', full_name='aom_api.TrialStartReply.initial_sim_state', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=439,
  serialized_end=558,
)


_TRIALENDREQUEST = _descriptor.Descriptor(
  name='TrialEndRequest',
  full_name='aom_api.TrialEndRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='session_id', full_name='aom_api.TrialEndRequest.session_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=560,
  serialized_end=597,
)


_TRIALENDREPLY = _descriptor.Descriptor(
  name='TrialEndReply',
  full_name='aom_api.TrialEndReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=599,
  serialized_end=614,
)


_TRIALACTIONREQUEST = _descriptor.Descriptor(
  name='TrialActionRequest',
  full_name='aom_api.TrialActionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='session_id', full_name='aom_api.TrialActionRequest.session_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content', full_name='aom_api.TrialActionRequest.content', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=616,
  serialized_end=673,
)


_TRIALACTIONREPLY = _descriptor.Descriptor(
  name='TrialActionReply',
  full_name='aom_api.TrialActionReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='delta', full_name='aom_api.TrialActionReply.delta', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=675,
  serialized_end=732,
)


_TRIALREWARDVALUE = _descriptor.Descriptor(
  name='TrialRewardValue',
  full_name='aom_api.TrialRewardValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='session_id', full_name='aom_api.TrialRewardValue.session_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=734,
  serialized_end=772,
)


_TRIALREWARDREQUEST = _descriptor.Descriptor(
  name='TrialRewardRequest',
  full_name='aom_api.TrialRewardRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='session_id', full_name='aom_api.TrialRewardRequest.session_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reward', full_name='aom_api.TrialRewardRequest.reward', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=774,
  serialized_end=852,
)


_TRIALREWARDREPLY = _descriptor.Descriptor(
  name='TrialRewardReply',
  full_name='aom_api.TrialRewardReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=854,
  serialized_end=872,
)


_ENVSTARTREQUEST = _descriptor.Descriptor(
  name='EnvStartRequest',
  full_name='aom_api.EnvStartRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='session_id', full_name='aom_api.EnvStartRequest.session_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_request', full_name='aom_api.EnvStartRequest.user_request', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=874,
  serialized_end=961,
)


_ENVSTARTREPLY = _descriptor.Descriptor(
  name='EnvStartReply',
  full_name='aom_api.EnvStartReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='session_id', full_name='aom_api.EnvStartReply.session_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='initial_sim_state', full_name='aom_api.EnvStartReply.initial_sim_state', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=963,
  serialized_end=1044,
)


_ENVUPDATEREQUEST_USERDATA = _descriptor.Descriptor(
  name='UserData',
  full_name='aom_api.EnvUpdateRequest.UserData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='content', full_name='aom_api.EnvUpdateRequest.UserData.content', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1213,
  serialized_end=1240,
)

_ENVUPDATEREQUEST = _descriptor.Descriptor(
  name='EnvUpdateRequest',
  full_name='aom_api.EnvUpdateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='session_id', full_name='aom_api.EnvUpdateRequest.session_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_data', full_name='aom_api.EnvUpdateRequest.user_data', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='agent_data', full_name='aom_api.EnvUpdateRequest.agent_data', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='create_checkpoint', full_name='aom_api.EnvUpdateRequest.create_checkpoint', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_ENVUPDATEREQUEST_USERDATA, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1047,
  serialized_end=1240,
)


_ENVUPDATEREPLY = _descriptor.Descriptor(
  name='EnvUpdateReply',
  full_name='aom_api.EnvUpdateReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='delta', full_name='aom_api.EnvUpdateReply.delta', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='env_state', full_name='aom_api.EnvUpdateReply.env_state', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rewards', full_name='aom_api.EnvUpdateReply.rewards', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1243,
  serialized_end=1375,
)


_AGENTSTARTREQUEST = _descriptor.Descriptor(
  name='AgentStartRequest',
  full_name='aom_api.AgentStartRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='session_id', full_name='aom_api.AgentStartRequest.session_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_request', full_name='aom_api.AgentStartRequest.user_request', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1377,
  serialized_end=1466,
)


_AGENTSTARTREPLY = _descriptor.Descriptor(
  name='AgentStartReply',
  full_name='aom_api.AgentStartReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1468,
  serialized_end=1485,
)


_AGENTDECIDEREQUEST = _descriptor.Descriptor(
  name='AgentDecideRequest',
  full_name='aom_api.AgentDecideRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='session_id', full_name='aom_api.AgentDecideRequest.session_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='env_state', full_name='aom_api.AgentDecideRequest.env_state', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='env_delta', full_name='aom_api.AgentDecideRequest.env_delta', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1487,
  serialized_end=1608,
)


_AGENTDECIDEREPLY = _descriptor.Descriptor(
  name='AgentDecideReply',
  full_name='aom_api.AgentDecideReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='decision', full_name='aom_api.AgentDecideReply.decision', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1610,
  serialized_end=1670,
)


_AGENTREWARDREQUEST = _descriptor.Descriptor(
  name='AgentRewardRequest',
  full_name='aom_api.AgentRewardRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='session_id', full_name='aom_api.AgentRewardRequest.session_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reward', full_name='aom_api.AgentRewardRequest.reward', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1672,
  serialized_end=1750,
)


_AGENTREWARDREPLY = _descriptor.Descriptor(
  name='AgentRewardReply',
  full_name='aom_api.AgentRewardReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1752,
  serialized_end=1770,
)


_DATALOG_SAMPLE = _descriptor.Descriptor(
  name='Datalog_sample',
  full_name='aom_api.Datalog_sample',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='trial_id', full_name='aom_api.Datalog_sample.trial_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='aom_api.Datalog_sample.time_stamp', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='env_state', full_name='aom_api.Datalog_sample.env_state', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='env_delta', full_name='aom_api.Datalog_sample.env_delta', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='agent_action', full_name='aom_api.Datalog_sample.agent_action', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_action', full_name='aom_api.Datalog_sample.user_action', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='agent_reward', full_name='aom_api.Datalog_sample.agent_reward', index=6,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_reward', full_name='aom_api.Datalog_sample.user_reward', index=7,
      number=8, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1773,
  serialized_end=1979,
)

_ENVSTATE.fields_by_name['time_stamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ENVSTATEDELTA.fields_by_name['time_stamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TRIALSTARTREPLY.fields_by_name['initial_sim_state'].message_type = _ENVSTATE
_TRIALACTIONREPLY.fields_by_name['delta'].message_type = _ENVSTATEDELTA
_TRIALREWARDREQUEST.fields_by_name['reward'].message_type = _REWARDEVENT
_ENVSTARTREQUEST.fields_by_name['user_request'].message_type = _TRIALSTARTREQUEST
_ENVSTARTREPLY.fields_by_name['initial_sim_state'].message_type = _ENVSTATE
_ENVUPDATEREQUEST_USERDATA.containing_type = _ENVUPDATEREQUEST
_ENVUPDATEREQUEST.fields_by_name['user_data'].message_type = _ENVUPDATEREQUEST_USERDATA
_ENVUPDATEREQUEST.fields_by_name['agent_data'].message_type = _AGENTDECISION
_ENVUPDATEREPLY.fields_by_name['delta'].message_type = _ENVSTATEDELTA
_ENVUPDATEREPLY.fields_by_name['env_state'].message_type = _ENVSTATE
_ENVUPDATEREPLY.fields_by_name['rewards'].message_type = _REWARDEVENT
_AGENTSTARTREQUEST.fields_by_name['user_request'].message_type = _TRIALSTARTREQUEST
_AGENTDECIDEREQUEST.fields_by_name['env_state'].message_type = _ENVSTATE
_AGENTDECIDEREQUEST.fields_by_name['env_delta'].message_type = _ENVSTATEDELTA
_AGENTDECIDEREPLY.fields_by_name['decision'].message_type = _AGENTDECISION
_AGENTREWARDREQUEST.fields_by_name['reward'].message_type = _REWARDEVENT
_DATALOG_SAMPLE.fields_by_name['time_stamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['EnvState'] = _ENVSTATE
DESCRIPTOR.message_types_by_name['EnvStateDelta'] = _ENVSTATEDELTA
DESCRIPTOR.message_types_by_name['RewardEvent'] = _REWARDEVENT
DESCRIPTOR.message_types_by_name['AgentDecision'] = _AGENTDECISION
DESCRIPTOR.message_types_by_name['TrialStartRequest'] = _TRIALSTARTREQUEST
DESCRIPTOR.message_types_by_name['TrialStartReply'] = _TRIALSTARTREPLY
DESCRIPTOR.message_types_by_name['TrialEndRequest'] = _TRIALENDREQUEST
DESCRIPTOR.message_types_by_name['TrialEndReply'] = _TRIALENDREPLY
DESCRIPTOR.message_types_by_name['TrialActionRequest'] = _TRIALACTIONREQUEST
DESCRIPTOR.message_types_by_name['TrialActionReply'] = _TRIALACTIONREPLY
DESCRIPTOR.message_types_by_name['TrialRewardValue'] = _TRIALREWARDVALUE
DESCRIPTOR.message_types_by_name['TrialRewardRequest'] = _TRIALREWARDREQUEST
DESCRIPTOR.message_types_by_name['TrialRewardReply'] = _TRIALREWARDREPLY
DESCRIPTOR.message_types_by_name['EnvStartRequest'] = _ENVSTARTREQUEST
DESCRIPTOR.message_types_by_name['EnvStartReply'] = _ENVSTARTREPLY
DESCRIPTOR.message_types_by_name['EnvUpdateRequest'] = _ENVUPDATEREQUEST
DESCRIPTOR.message_types_by_name['EnvUpdateReply'] = _ENVUPDATEREPLY
DESCRIPTOR.message_types_by_name['AgentStartRequest'] = _AGENTSTARTREQUEST
DESCRIPTOR.message_types_by_name['AgentStartReply'] = _AGENTSTARTREPLY
DESCRIPTOR.message_types_by_name['AgentDecideRequest'] = _AGENTDECIDEREQUEST
DESCRIPTOR.message_types_by_name['AgentDecideReply'] = _AGENTDECIDEREPLY
DESCRIPTOR.message_types_by_name['AgentRewardRequest'] = _AGENTREWARDREQUEST
DESCRIPTOR.message_types_by_name['AgentRewardReply'] = _AGENTREWARDREPLY
DESCRIPTOR.message_types_by_name['Datalog_sample'] = _DATALOG_SAMPLE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

EnvState = _reflection.GeneratedProtocolMessageType('EnvState', (_message.Message,), dict(
  DESCRIPTOR = _ENVSTATE,
  __module__ = 'aom_framework.protocols_pb2'
  # @@protoc_insertion_point(class_scope:aom_api.EnvState)
  ))
_sym_db.RegisterMessage(EnvState)

EnvStateDelta = _reflection.GeneratedProtocolMessageType('EnvStateDelta', (_message.Message,), dict(
  DESCRIPTOR = _ENVSTATEDELTA,
  __module__ = 'aom_framework.protocols_pb2'
  # @@protoc_insertion_point(class_scope:aom_api.EnvStateDelta)
  ))
_sym_db.RegisterMessage(EnvStateDelta)

RewardEvent = _reflection.GeneratedProtocolMessageType('RewardEvent', (_message.Message,), dict(
  DESCRIPTOR = _REWARDEVENT,
  __module__ = 'aom_framework.protocols_pb2'
  # @@protoc_insertion_point(class_scope:aom_api.RewardEvent)
  ))
_sym_db.RegisterMessage(RewardEvent)

AgentDecision = _reflection.GeneratedProtocolMessageType('AgentDecision', (_message.Message,), dict(
  DESCRIPTOR = _AGENTDECISION,
  __module__ = 'aom_framework.protocols_pb2'
  # @@protoc_insertion_point(class_scope:aom_api.AgentDecision)
  ))
_sym_db.RegisterMessage(AgentDecision)

TrialStartRequest = _reflection.GeneratedProtocolMessageType('TrialStartRequest', (_message.Message,), dict(
  DESCRIPTOR = _TRIALSTARTREQUEST,
  __module__ = 'aom_framework.protocols_pb2'
  # @@protoc_insertion_point(class_scope:aom_api.TrialStartRequest)
  ))
_sym_db.RegisterMessage(TrialStartRequest)

TrialStartReply = _reflection.GeneratedProtocolMessageType('TrialStartReply', (_message.Message,), dict(
  DESCRIPTOR = _TRIALSTARTREPLY,
  __module__ = 'aom_framework.protocols_pb2'
  # @@protoc_insertion_point(class_scope:aom_api.TrialStartReply)
  ))
_sym_db.RegisterMessage(TrialStartReply)

TrialEndRequest = _reflection.GeneratedProtocolMessageType('TrialEndRequest', (_message.Message,), dict(
  DESCRIPTOR = _TRIALENDREQUEST,
  __module__ = 'aom_framework.protocols_pb2'
  # @@protoc_insertion_point(class_scope:aom_api.TrialEndRequest)
  ))
_sym_db.RegisterMessage(TrialEndRequest)

TrialEndReply = _reflection.GeneratedProtocolMessageType('TrialEndReply', (_message.Message,), dict(
  DESCRIPTOR = _TRIALENDREPLY,
  __module__ = 'aom_framework.protocols_pb2'
  # @@protoc_insertion_point(class_scope:aom_api.TrialEndReply)
  ))
_sym_db.RegisterMessage(TrialEndReply)

TrialActionRequest = _reflection.GeneratedProtocolMessageType('TrialActionRequest', (_message.Message,), dict(
  DESCRIPTOR = _TRIALACTIONREQUEST,
  __module__ = 'aom_framework.protocols_pb2'
  # @@protoc_insertion_point(class_scope:aom_api.TrialActionRequest)
  ))
_sym_db.RegisterMessage(TrialActionRequest)

TrialActionReply = _reflection.GeneratedProtocolMessageType('TrialActionReply', (_message.Message,), dict(
  DESCRIPTOR = _TRIALACTIONREPLY,
  __module__ = 'aom_framework.protocols_pb2'
  # @@protoc_insertion_point(class_scope:aom_api.TrialActionReply)
  ))
_sym_db.RegisterMessage(TrialActionReply)

TrialRewardValue = _reflection.GeneratedProtocolMessageType('TrialRewardValue', (_message.Message,), dict(
  DESCRIPTOR = _TRIALREWARDVALUE,
  __module__ = 'aom_framework.protocols_pb2'
  # @@protoc_insertion_point(class_scope:aom_api.TrialRewardValue)
  ))
_sym_db.RegisterMessage(TrialRewardValue)

TrialRewardRequest = _reflection.GeneratedProtocolMessageType('TrialRewardRequest', (_message.Message,), dict(
  DESCRIPTOR = _TRIALREWARDREQUEST,
  __module__ = 'aom_framework.protocols_pb2'
  # @@protoc_insertion_point(class_scope:aom_api.TrialRewardRequest)
  ))
_sym_db.RegisterMessage(TrialRewardRequest)

TrialRewardReply = _reflection.GeneratedProtocolMessageType('TrialRewardReply', (_message.Message,), dict(
  DESCRIPTOR = _TRIALREWARDREPLY,
  __module__ = 'aom_framework.protocols_pb2'
  # @@protoc_insertion_point(class_scope:aom_api.TrialRewardReply)
  ))
_sym_db.RegisterMessage(TrialRewardReply)

EnvStartRequest = _reflection.GeneratedProtocolMessageType('EnvStartRequest', (_message.Message,), dict(
  DESCRIPTOR = _ENVSTARTREQUEST,
  __module__ = 'aom_framework.protocols_pb2'
  # @@protoc_insertion_point(class_scope:aom_api.EnvStartRequest)
  ))
_sym_db.RegisterMessage(EnvStartRequest)

EnvStartReply = _reflection.GeneratedProtocolMessageType('EnvStartReply', (_message.Message,), dict(
  DESCRIPTOR = _ENVSTARTREPLY,
  __module__ = 'aom_framework.protocols_pb2'
  # @@protoc_insertion_point(class_scope:aom_api.EnvStartReply)
  ))
_sym_db.RegisterMessage(EnvStartReply)

EnvUpdateRequest = _reflection.GeneratedProtocolMessageType('EnvUpdateRequest', (_message.Message,), dict(

  UserData = _reflection.GeneratedProtocolMessageType('UserData', (_message.Message,), dict(
    DESCRIPTOR = _ENVUPDATEREQUEST_USERDATA,
    __module__ = 'aom_framework.protocols_pb2'
    # @@protoc_insertion_point(class_scope:aom_api.EnvUpdateRequest.UserData)
    ))
  ,
  DESCRIPTOR = _ENVUPDATEREQUEST,
  __module__ = 'aom_framework.protocols_pb2'
  # @@protoc_insertion_point(class_scope:aom_api.EnvUpdateRequest)
  ))
_sym_db.RegisterMessage(EnvUpdateRequest)
_sym_db.RegisterMessage(EnvUpdateRequest.UserData)

EnvUpdateReply = _reflection.GeneratedProtocolMessageType('EnvUpdateReply', (_message.Message,), dict(
  DESCRIPTOR = _ENVUPDATEREPLY,
  __module__ = 'aom_framework.protocols_pb2'
  # @@protoc_insertion_point(class_scope:aom_api.EnvUpdateReply)
  ))
_sym_db.RegisterMessage(EnvUpdateReply)

AgentStartRequest = _reflection.GeneratedProtocolMessageType('AgentStartRequest', (_message.Message,), dict(
  DESCRIPTOR = _AGENTSTARTREQUEST,
  __module__ = 'aom_framework.protocols_pb2'
  # @@protoc_insertion_point(class_scope:aom_api.AgentStartRequest)
  ))
_sym_db.RegisterMessage(AgentStartRequest)

AgentStartReply = _reflection.GeneratedProtocolMessageType('AgentStartReply', (_message.Message,), dict(
  DESCRIPTOR = _AGENTSTARTREPLY,
  __module__ = 'aom_framework.protocols_pb2'
  # @@protoc_insertion_point(class_scope:aom_api.AgentStartReply)
  ))
_sym_db.RegisterMessage(AgentStartReply)

AgentDecideRequest = _reflection.GeneratedProtocolMessageType('AgentDecideRequest', (_message.Message,), dict(
  DESCRIPTOR = _AGENTDECIDEREQUEST,
  __module__ = 'aom_framework.protocols_pb2'
  # @@protoc_insertion_point(class_scope:aom_api.AgentDecideRequest)
  ))
_sym_db.RegisterMessage(AgentDecideRequest)

AgentDecideReply = _reflection.GeneratedProtocolMessageType('AgentDecideReply', (_message.Message,), dict(
  DESCRIPTOR = _AGENTDECIDEREPLY,
  __module__ = 'aom_framework.protocols_pb2'
  # @@protoc_insertion_point(class_scope:aom_api.AgentDecideReply)
  ))
_sym_db.RegisterMessage(AgentDecideReply)

AgentRewardRequest = _reflection.GeneratedProtocolMessageType('AgentRewardRequest', (_message.Message,), dict(
  DESCRIPTOR = _AGENTREWARDREQUEST,
  __module__ = 'aom_framework.protocols_pb2'
  # @@protoc_insertion_point(class_scope:aom_api.AgentRewardRequest)
  ))
_sym_db.RegisterMessage(AgentRewardRequest)

AgentRewardReply = _reflection.GeneratedProtocolMessageType('AgentRewardReply', (_message.Message,), dict(
  DESCRIPTOR = _AGENTREWARDREPLY,
  __module__ = 'aom_framework.protocols_pb2'
  # @@protoc_insertion_point(class_scope:aom_api.AgentRewardReply)
  ))
_sym_db.RegisterMessage(AgentRewardReply)

Datalog_sample = _reflection.GeneratedProtocolMessageType('Datalog_sample', (_message.Message,), dict(
  DESCRIPTOR = _DATALOG_SAMPLE,
  __module__ = 'aom_framework.protocols_pb2'
  # @@protoc_insertion_point(class_scope:aom_api.Datalog_sample)
  ))
_sym_db.RegisterMessage(Datalog_sample)


# @@protoc_insertion_point(module_scope)
